@@ -29,8 +29,6 @@ namespace KWayland
 namespace Server
 {
 
-static const quint32 s_version = 3;
-
 class CompositorInterface::Private : public Global::Private
 {
 public:
@@ -50,18 +48,23 @@ private:
 
     CompositorInterface *q;
     static const struct wl_compositor_interface s_interface;
+    static const quint32 s_version;
 };
 
+const quint32 CompositorInterface::Private::s_version = 3;
+
 CompositorInterface::Private::Private(CompositorInterface *q, Display *d)
     : Global::Private(d, &wl_compositor_interface, s_version)
     , q(q)
 {
 }
 
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
 const struct wl_compositor_interface CompositorInterface::Private::s_interface = {
     createSurfaceCallback,
     createRegionCallback
 };
+#endif
 
 CompositorInterface::CompositorInterface(Display *display, QObject *parent)
     : Global(new Private(this, display), parent)
@@ -103,7 +106,7 @@ void CompositorInterface::Private::createSurface(wl_client *client, wl_resource
         return;
     }
     QObject::connect(surface->client(), &ClientConnection::disconnected, surface,
-        [surface] (ClientConnection *c) {
+        [surface] {
             if (surface->resource()) {
                 wl_resource_destroy(surface->resource());
                 delete surface;
@@ -128,7 +131,7 @@ void CompositorInterface::Private::createRegion(wl_client *client, wl_resource *
         return;
     }
     QObject::connect(region->client(), &ClientConnection::disconnected, region,
-        [region] (ClientConnection *c) {
+        [region] {
             if (region->resource()) {
                 wl_resource_destroy(region->resource());
                 delete region;
