@@ -21,6 +21,8 @@ License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 #include "global_p.h"
 #include "display.h"
 
+#include <QVector>
+
 #include <wayland-server.h>
 
 namespace KWayland
@@ -28,8 +30,6 @@ namespace KWayland
 namespace Server
 {
 
-static const quint32 s_version = 2;
-
 class OutputInterface::Private : public Global::Private
 {
 public:
@@ -38,6 +38,7 @@ public:
         uint32_t version;
     };
     Private(OutputInterface *q, Display *d);
+    ~Private();
     void sendMode(wl_resource *resource, const Mode &mode);
     void sendDone(const ResourceData &data);
     void updateGeometry();
@@ -52,8 +53,15 @@ public:
     Transform transform = Transform::Normal;
     QList<Mode> modes;
     QList<ResourceData> resources;
+    struct {
+        DpmsMode mode = DpmsMode::On;
+        bool supported = false;
+    } dpms;
+
+    static OutputInterface *get(wl_resource *native);
 
 private:
+    static Private *cast(wl_resource *native);
     static void unbind(wl_resource *resource);
     void bind(wl_client *client, uint32_t version, uint32_t id) override;
     int32_t toTransform() const;
@@ -62,12 +70,43 @@ private:
     void sendScale(const ResourceData &data);
 
     OutputInterface *q;
+    static QVector<Private*> s_privates;
+    static const quint32 s_version;
 };
 
+QVector<OutputInterface::Private*> OutputInterface::Private::s_privates;
+const quint32 OutputInterface::Private::s_version = 2;
+
 OutputInterface::Private::Private(OutputInterface *q, Display *d)
     : Global::Private(d, &wl_output_interface, s_version)
     , q(q)
 {
+    s_privates << this;
+}
+
+OutputInterface::Private::~Private()
+{
+    s_privates.removeAll(this);
+}
+
+OutputInterface *OutputInterface::Private::get(wl_resource *native)
+{
+    if (Private *p = cast(native)) {
+        return p->q;
+    }
+    return nullptr;
+}
+
+OutputInterface::Private *OutputInterface::Private::cast(wl_resource *native)
+{
+    for (auto it = s_privates.constBegin(); it != s_privates.constEnd(); ++it) {
+        const auto &resources = (*it)->resources;
+        auto rit = std::find_if(resources.begin(), resources.end(), [native] (const ResourceData &data) { return data.resource == native; });
+        if (rit != resources.end()) {
+            return (*it);
+        }
+    }
+    return nullptr;
 }
 
 OutputInterface::OutputInterface(Display *display, QObject *parent)
@@ -294,7 +333,10 @@ void OutputInterface::Private::bind(wl_client *client, uint32_t version, uint32_
 
 void OutputInterface::Private::unbind(wl_resource *resource)
 {
-    auto o = reinterpret_cast<OutputInterface::Private*>(wl_resource_get_user_data(resource));
+    Private *o = cast(resource);
+    if (!o) {
+        return;
+    }
     auto it = std::find_if(o->resources.begin(), o->resources.end(), [resource](const ResourceData &r) { return r.resource == resource; });
     if (it != o->resources.end()) {
         o->resources.erase(it);
@@ -432,6 +474,43 @@ QList< OutputInterface::Mode > OutputInterface::modes() const
     return d->modes;
 }
 
+void OutputInterface::setDpmsMode(OutputInterface::DpmsMode mode)
+{
+    Q_D();
+    if (d->dpms.mode == mode) {
+        return;
+    }
+    d->dpms.mode = mode;
+    emit dpmsModeChanged();
+}
+
+void OutputInterface::setDpmsSupported(bool supported)
+{
+    Q_D();
+    if (d->dpms.supported == supported) {
+        return;
+    }
+    d->dpms.supported = supported;
+    emit dpmsSupportedChanged();
+}
+
+OutputInterface::DpmsMode OutputInterface::dpmsMode() const
+{
+    Q_D();
+    return d->dpms.mode;
+}
+
+bool OutputInterface::isDpmsSupported() const
+{
+    Q_D();
+    return d->dpms.supported;
+}
+
+OutputInterface *OutputInterface::get(wl_resource* native)
+{
+    return Private::get(native);
+}
+
 OutputInterface::Private *OutputInterface::d_func() const
 {
     return reinterpret_cast<Private*>(d.data());
