@@ -38,7 +38,10 @@ namespace KWayland
 namespace Server
 {
 
-static const quint32 s_version = 3;
+const quint32 SeatInterface::Private::s_version = 4;
+const qint32 SeatInterface::Private::s_pointerVersion = 3;
+const qint32 SeatInterface::Private::s_touchVersion = 3;
+const qint32 SeatInterface::Private::s_keyboardVersion = 4;
 
 SeatInterface::Private::Private(SeatInterface *q, Display *display)
     : Global::Private(display, &wl_seat_interface, s_version)
@@ -46,11 +49,13 @@ SeatInterface::Private::Private(SeatInterface *q, Display *display)
 {
 }
 
+#ifndef DOXYGEN_SHOULD_SKIP_THIS
 const struct wl_seat_interface SeatInterface::Private::s_interface = {
     getPointerCallback,
     getKeyboardCallback,
     getTouchCallback
 };
+#endif
 
 SeatInterface::SeatInterface(Display *display, QObject *parent)
     : Global(new Private(this, display), parent)
@@ -159,6 +164,7 @@ SeatInterface::Private *SeatInterface::Private::cast(wl_resource *r)
     return r ? reinterpret_cast<SeatInterface::Private*>(wl_resource_get_user_data(r)) : nullptr;
 }
 
+namespace {
 template <typename T>
 static
 T *interfaceForSurface(SurfaceInterface *surface, const QVector<T*> &interfaces)
@@ -174,6 +180,7 @@ T *interfaceForSurface(SurfaceInterface *surface, const QVector<T*> &interfaces)
     }
     return nullptr;
 }
+}
 
 PointerInterface *SeatInterface::Private::pointerForSurface(SurfaceInterface *surface) const
 {
@@ -303,7 +310,7 @@ void SeatInterface::Private::getPointer(wl_client *client, wl_resource *resource
 {
     // TODO: only create if seat has pointer?
     PointerInterface *pointer = new PointerInterface(q, resource);
-    pointer->create(display->getConnection(client), wl_resource_get_version(resource), id);
+    pointer->create(display->getConnection(client), qMin(wl_resource_get_version(resource), s_pointerVersion), id);
     if (!pointer->resource()) {
         wl_resource_post_no_memory(resource);
         delete pointer;
@@ -337,12 +344,13 @@ void SeatInterface::Private::getKeyboard(wl_client *client, wl_resource *resourc
 {
     // TODO: only create if seat has keyboard?
     KeyboardInterface *keyboard = new KeyboardInterface(q, resource);
-    keyboard->create(display->getConnection(client), wl_resource_get_version(resource), id);
+    keyboard->create(display->getConnection(client), qMin(wl_resource_get_version(resource), s_keyboardVersion) , id);
     if (!keyboard->resource()) {
         wl_resource_post_no_memory(resource);
         delete keyboard;
         return;
     }
+    keyboard->repeatInfo(keys.keyRepeat.charactersPerSecond, keys.keyRepeat.delay);
     if (keys.keymap.xkbcommonCompatible) {
         keyboard->setKeymap(keys.keymap.fd, keys.keymap.size);
     }
@@ -374,7 +382,7 @@ void SeatInterface::Private::getTouch(wl_client *client, wl_resource *resource,
 {
     // TODO: only create if seat has touch?
     TouchInterface *touch = new TouchInterface(q, resource);
-    touch->create(display->getConnection(client), wl_resource_get_version(resource), id);
+    touch->create(display->getConnection(client), qMin(wl_resource_get_version(resource), s_touchVersion), id);
     if (!touch->resource()) {
         wl_resource_post_no_memory(resource);
         delete touch;
@@ -526,6 +534,7 @@ QPointF SeatInterface::focusedPointerSurfacePosition() const
     return d->globalPointer.focus.offset;
 }
 
+namespace {
 static quint32 qtToWaylandButton(Qt::MouseButton button)
 {
     static const QHash<Qt::MouseButton, quint32> s_buttons({
@@ -548,7 +557,8 @@ static quint32 qtToWaylandButton(Qt::MouseButton button)
         // further mapping not possible, 0x120 is BTN_JOYSTICK
     });
     return s_buttons.value(button, 0);
-};
+}
+}
 
 bool SeatInterface::isPointerButtonPressed(Qt::MouseButton button) const
 {
@@ -718,6 +728,28 @@ void SeatInterface::updateKeyboardModifiers(quint32 depressed, quint32 latched,
     }
 }
 
+void SeatInterface::setKeyRepeatInfo(qint32 charactersPerSecond, qint32 delay)
+{
+    Q_D();
+    d->keys.keyRepeat.charactersPerSecond = qMax(charactersPerSecond, 0);
+    d->keys.keyRepeat.delay = qMax(delay, 0);
+    for (auto it = d->keyboards.constBegin(); it != d->keyboards.constEnd(); ++it) {
+        (*it)->repeatInfo(d->keys.keyRepeat.charactersPerSecond, d->keys.keyRepeat.delay);
+    }
+}
+
+qint32 SeatInterface::keyRepeatDelay() const
+{
+    Q_D();
+    return d->keys.keyRepeat.delay;
+}
+
+qint32 SeatInterface::keyRepeatRate() const
+{
+    Q_D();
+    return d->keys.keyRepeat.charactersPerSecond;
+}
+
 bool SeatInterface::isKeymapXkbCompatible() const
 {
     Q_D();
@@ -871,6 +903,8 @@ qint32 SeatInterface::touchDown(const QPointF &globalPosition)
         wl_pointer_send_enter(p->resource(), serial,
                           focusedTouchSurface()->resource(),
                           wl_fixed_from_double(pos.x()), wl_fixed_from_double(pos.y()));
+        wl_pointer_send_motion(p->resource(), timestamp(),
+                                wl_fixed_from_double(pos.x()), wl_fixed_from_double(pos.y()));
 
         wl_pointer_send_button(p->resource(), serial, timestamp(), BTN_LEFT, WL_POINTER_BUTTON_STATE_PRESSED);
     }
