@@ -112,6 +112,10 @@ public:
         };
         Focus focus;
         quint32 lastStateSerial = 0;
+        struct {
+            qint32 charactersPerSecond = 0;
+            qint32 delay = 0;
+        } keyRepeat;
     };
     Keyboard keys;
     void updateKey(quint32 key, Keyboard::State state);
@@ -146,6 +150,10 @@ private:
     static void getKeyboardCallback(wl_client *client, wl_resource *resource, uint32_t id);
     static void getTouchCallback(wl_client *client, wl_resource *resource, uint32_t id);
     static const struct wl_seat_interface s_interface;
+    static const quint32 s_version;
+    static const qint32 s_pointerVersion;
+    static const qint32 s_touchVersion;
+    static const qint32 s_keyboardVersion;
 
     SeatInterface *q;
 };
