@@ -41,6 +41,9 @@ public:
         bool opaqueIsSet = false;
         bool bufferIsSet = false;
         bool shadowIsSet = false;
+        bool blurIsSet = false;
+        bool contrastIsSet = false;
+        bool slideIsSet = false;
         bool inputIsInfinite = true;
         qint32 scale = 1;
         OutputInterface::Transform transform = OutputInterface::Transform::Normal;
@@ -50,6 +53,9 @@ public:
         // stacking order: bottom (first) -> top (last)
         QList<QPointer<SubSurfaceInterface>> children;
         QPointer<ShadowInterface> shadow;
+        QPointer<BlurInterface> blur;
+        QPointer<ContrastInterface> contrast;
+        QPointer<SlideInterface> slide;
     };
     Private(SurfaceInterface *q, CompositorInterface *c, wl_resource *parentResource);
     ~Private();
@@ -61,6 +67,9 @@ public:
     bool raiseChild(QPointer<SubSurfaceInterface> subsurface, SurfaceInterface *sibling);
     bool lowerChild(QPointer<SubSurfaceInterface> subsurface, SurfaceInterface *sibling);
     void setShadow(const QPointer<ShadowInterface> &shadow);
+    void setBlur(const QPointer<BlurInterface> &blur);
+    void setContrast(const QPointer<ContrastInterface> &contrast);
+    void setSlide(const QPointer<SlideInterface> &slide);
 
     State current;
     State pending;
